@@ -16,7 +16,8 @@ class LogzioHandler(logging.Handler):
                  logzio_type="python",
                  logs_drain_timeout=3,
                  url="https://listener.logz.io:8071",
-                 debug=False):
+                 debug=False,
+                 backup_logs=True):
 
         if not token:
             raise LogzioException('Logz.io Token must be provided')
@@ -27,7 +28,8 @@ class LogzioHandler(logging.Handler):
             token=token,
             url=url,
             logs_drain_timeout=logs_drain_timeout,
-            debug=debug)
+            debug=debug,
+            backup_logs=backup_logs)
         logging.Handler.__init__(self)
 
     def extra_fields(self, message):
@@ -86,15 +88,19 @@ class LogzioHandler(logging.Handler):
 
         if message.exc_info:
             return_json['exception'] = self.format_exception(message.exc_info)
+
+            # We want to ignore default logging formatting on exceptions
+            # As we handle those differently directly into exception field
+            message.exc_info = None
+            message.exc_text = None
+
+        formatted_message = self.format(message)
+        if isinstance(formatted_message, dict):
+            return_json.update(formatted_message)
         else:
-            formatted_message = self.format(message)
-            return_json.update(self.extra_fields(message))
-
-            if isinstance(formatted_message, dict):
-                return_json.update(formatted_message)
-            else:
-                return_json['message'] = formatted_message
+            return_json['message'] = formatted_message
 
+        return_json.update(self.extra_fields(message))
         return return_json
 
     def emit(self, record):
